r'''
# netapp-fsxn-clusterpeer

> AWS CDK [L1 construct](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html) and data structures for the [AWS CloudFormation Registry](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry.html) type `NetApp::FSxN::ClusterPeer` v1.1.0.

## Description

A cluster peer establishes a trusted network relationship between two FSx for ONTAP file systems, allowing them to securely communicate and replicate encrypted, authenticated data. It is used for disaster recovery across clusters in different regions, providing flexibility for data protection and high availability. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.

## References

* [Source](https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider)

## Usage

In order to use this library, you will need to activate this AWS CloudFormation Registry type in your account. You can do this via the AWS Management Console or using the [AWS CLI](https://aws.amazon.com/cli/) using the following command:

```sh
aws cloudformation activate-type \
  --type-name NetApp::FSxN::ClusterPeer \
  --publisher-id a25d267c2b9b86b8d408fce3c7a4d94d34c90946 \
  --type RESOURCE \
  --execution-role-arn ROLE-ARN
```

Alternatively:

```sh
aws cloudformation activate-type \
  --public-type-arn arn:aws:cloudformation:us-east-1::type/resource/a25d267c2b9b86b8d408fce3c7a4d94d34c90946/NetApp-FSxN-ClusterPeer \
  --execution-role-arn ROLE-ARN
```

You can find more information about activating this type in the [AWS CloudFormation documentation](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html).

## Feedback

This library is auto-generated and published to all supported programming languages by the [cdklabs/cdk-cloudformation](https://github.com/cdklabs/cdk-cloudformation) project based on the API schema published for `NetApp::FSxN::ClusterPeer`.

* Issues related to this generated library should be [reported here](https://github.com/cdklabs/cdk-cloudformation/issues/new?title=Issue+with+%40cdk-cloudformation%2Fnetapp-fsxn-clusterpeer+v1.1.0).
* Issues related to `NetApp::FSxN::ClusterPeer` should be reported to the [publisher](https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider).

## License

Distributed under the Apache-2.0 License.
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

import aws_cdk as _aws_cdk_ceddda9d
import constructs as _constructs_77d1e7e8


class CfnClusterPeer(
    _aws_cdk_ceddda9d.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.CfnClusterPeer",
):
    '''A CloudFormation ``NetApp::FSxN::ClusterPeer``.

    :cloudformationResource: NetApp::FSxN::ClusterPeer
    :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        fsxn_destination_info: typing.Union["FsxnDestination", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
        destination_cluster_peer: typing.Optional[typing.Union["ClusterPeerInfo", typing.Dict[builtins.str, typing.Any]]] = None,
        encryption: typing.Optional["CfnClusterPeerPropsEncryption"] = None,
        source_cluster_peer: typing.Optional[typing.Union["ClusterPeerInfo", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''Create a new ``NetApp::FSxN::ClusterPeer``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param fsxn_destination_info: The destination information for the Cluster Peer relationship.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.
        :param destination_cluster_peer: Information about the destination cluster peer, including name and IP addresses.
        :param encryption: Encryption mechanism of the communication channel between the two peers.
        :param source_cluster_peer: Information about the source cluster peer, including name and IP addresses.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__d39f67cfc2675a7cba4b59b49a311a2ad559e3e34f2bf2d63301ef90806e1673)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnClusterPeerProps(
            file_system_id=file_system_id,
            fsx_admin_password_source=fsx_admin_password_source,
            fsxn_destination_info=fsxn_destination_info,
            link_arn=link_arn,
            destination_cluster_peer=destination_cluster_peer,
            encryption=encryption,
            source_cluster_peer=source_cluster_peer,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrDestinationClusterPeerUUID")
    def attr_destination_cluster_peer_uuid(self) -> builtins.str:
        '''Attribute ``NetApp::FSxN::ClusterPeer.DestinationClusterPeerUUID``.

        :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrDestinationClusterPeerUUID"))

    @builtins.property
    @jsii.member(jsii_name="attrSourceClusterPeerUUID")
    def attr_source_cluster_peer_uuid(self) -> builtins.str:
        '''Attribute ``NetApp::FSxN::ClusterPeer.SourceClusterPeerUUID``.

        :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrSourceClusterPeerUUID"))

    @builtins.property
    @jsii.member(jsii_name="props")
    def props(self) -> "CfnClusterPeerProps":
        '''Resource props.'''
        return typing.cast("CfnClusterPeerProps", jsii.get(self, "props"))


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.CfnClusterPeerProps",
    jsii_struct_bases=[],
    name_mapping={
        "file_system_id": "fileSystemId",
        "fsx_admin_password_source": "fsxAdminPasswordSource",
        "fsxn_destination_info": "fsxnDestinationInfo",
        "link_arn": "linkArn",
        "destination_cluster_peer": "destinationClusterPeer",
        "encryption": "encryption",
        "source_cluster_peer": "sourceClusterPeer",
    },
)
class CfnClusterPeerProps:
    def __init__(
        self,
        *,
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        fsxn_destination_info: typing.Union["FsxnDestination", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
        destination_cluster_peer: typing.Optional[typing.Union["ClusterPeerInfo", typing.Dict[builtins.str, typing.Any]]] = None,
        encryption: typing.Optional["CfnClusterPeerPropsEncryption"] = None,
        source_cluster_peer: typing.Optional[typing.Union["ClusterPeerInfo", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''A cluster peer establishes a trusted network relationship between two FSx for ONTAP file systems, allowing them to securely communicate and replicate encrypted, authenticated data.

        It is used for disaster recovery across clusters in different regions, providing flexibility for data protection and high availability. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.

        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param fsxn_destination_info: The destination information for the Cluster Peer relationship.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.
        :param destination_cluster_peer: Information about the destination cluster peer, including name and IP addresses.
        :param encryption: Encryption mechanism of the communication channel between the two peers.
        :param source_cluster_peer: Information about the source cluster peer, including name and IP addresses.

        :schema: CfnClusterPeerProps
        '''
        if isinstance(fsx_admin_password_source, dict):
            fsx_admin_password_source = PasswordSource(**fsx_admin_password_source)
        if isinstance(fsxn_destination_info, dict):
            fsxn_destination_info = FsxnDestination(**fsxn_destination_info)
        if isinstance(destination_cluster_peer, dict):
            destination_cluster_peer = ClusterPeerInfo(**destination_cluster_peer)
        if isinstance(source_cluster_peer, dict):
            source_cluster_peer = ClusterPeerInfo(**source_cluster_peer)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__a4fff69eb8122f4cd873011b3c958000430d60ee8d1f6a645518139c95bfbc99)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument fsx_admin_password_source", value=fsx_admin_password_source, expected_type=type_hints["fsx_admin_password_source"])
            check_type(argname="argument fsxn_destination_info", value=fsxn_destination_info, expected_type=type_hints["fsxn_destination_info"])
            check_type(argname="argument link_arn", value=link_arn, expected_type=type_hints["link_arn"])
            check_type(argname="argument destination_cluster_peer", value=destination_cluster_peer, expected_type=type_hints["destination_cluster_peer"])
            check_type(argname="argument encryption", value=encryption, expected_type=type_hints["encryption"])
            check_type(argname="argument source_cluster_peer", value=source_cluster_peer, expected_type=type_hints["source_cluster_peer"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "file_system_id": file_system_id,
            "fsx_admin_password_source": fsx_admin_password_source,
            "fsxn_destination_info": fsxn_destination_info,
            "link_arn": link_arn,
        }
        if destination_cluster_peer is not None:
            self._values["destination_cluster_peer"] = destination_cluster_peer
        if encryption is not None:
            self._values["encryption"] = encryption
        if source_cluster_peer is not None:
            self._values["source_cluster_peer"] = source_cluster_peer

    @builtins.property
    def file_system_id(self) -> builtins.str:
        '''The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.

        :schema: CfnClusterPeerProps#FileSystemId
        '''
        result = self._values.get("file_system_id")
        assert result is not None, "Required property 'file_system_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def fsx_admin_password_source(self) -> "PasswordSource":
        '''The password source for the FSx admin user.

        :schema: CfnClusterPeerProps#FsxAdminPasswordSource
        '''
        result = self._values.get("fsx_admin_password_source")
        assert result is not None, "Required property 'fsx_admin_password_source' is missing"
        return typing.cast("PasswordSource", result)

    @builtins.property
    def fsxn_destination_info(self) -> "FsxnDestination":
        '''The destination information for the Cluster Peer relationship.

        :schema: CfnClusterPeerProps#FsxnDestinationInfo
        '''
        result = self._values.get("fsxn_destination_info")
        assert result is not None, "Required property 'fsxn_destination_info' is missing"
        return typing.cast("FsxnDestination", result)

    @builtins.property
    def link_arn(self) -> builtins.str:
        '''The ARN of the AWS Lambda function that will be invoked to manage the resource.

        :schema: CfnClusterPeerProps#LinkArn
        '''
        result = self._values.get("link_arn")
        assert result is not None, "Required property 'link_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def destination_cluster_peer(self) -> typing.Optional["ClusterPeerInfo"]:
        '''Information about the destination cluster peer, including name and IP addresses.

        :schema: CfnClusterPeerProps#DestinationClusterPeer
        '''
        result = self._values.get("destination_cluster_peer")
        return typing.cast(typing.Optional["ClusterPeerInfo"], result)

    @builtins.property
    def encryption(self) -> typing.Optional["CfnClusterPeerPropsEncryption"]:
        '''Encryption mechanism of the communication channel between the two peers.

        :schema: CfnClusterPeerProps#Encryption
        '''
        result = self._values.get("encryption")
        return typing.cast(typing.Optional["CfnClusterPeerPropsEncryption"], result)

    @builtins.property
    def source_cluster_peer(self) -> typing.Optional["ClusterPeerInfo"]:
        '''Information about the source cluster peer, including name and IP addresses.

        :schema: CfnClusterPeerProps#SourceClusterPeer
        '''
        result = self._values.get("source_cluster_peer")
        return typing.cast(typing.Optional["ClusterPeerInfo"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnClusterPeerProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.CfnClusterPeerPropsEncryption"
)
class CfnClusterPeerPropsEncryption(enum.Enum):
    '''Encryption mechanism of the communication channel between the two peers.

    :schema: CfnClusterPeerPropsEncryption
    '''

    NONE = "NONE"
    '''none.'''
    TLS_UNDERSCORE_PSK = "TLS_UNDERSCORE_PSK"
    '''tls_psk.'''


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.ClusterPeerInfo",
    jsii_struct_bases=[],
    name_mapping={
        "ip_space": "ipSpace",
        "name": "name",
        "remote_ip_addresses": "remoteIpAddresses",
        "status_info": "statusInfo",
    },
)
class ClusterPeerInfo:
    def __init__(
        self,
        *,
        ip_space: typing.Optional[builtins.str] = None,
        name: typing.Optional[builtins.str] = None,
        remote_ip_addresses: typing.Optional[typing.Sequence[builtins.str]] = None,
        status_info: typing.Optional[typing.Union["ClusterPeerStatus", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''
        :param ip_space: IPspace name of the local intercluster LIFs. Assumes Default IPspace if not provided.
        :param name: Optional name for the cluster peer relationship. By default, it is the name of the remote cluster.
        :param remote_ip_addresses: Addresses of the remote peers. Assumes existing intercluster LIFs of remote cluster if not provided.
        :param status_info: Status of the cluster peer relationship.

        :schema: ClusterPeerInfo
        '''
        if isinstance(status_info, dict):
            status_info = ClusterPeerStatus(**status_info)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__ae24ad49b7d1edca270fc0fd1fb3c66c71571d1e4e44b7ef2dbc0df5e3125026)
            check_type(argname="argument ip_space", value=ip_space, expected_type=type_hints["ip_space"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument remote_ip_addresses", value=remote_ip_addresses, expected_type=type_hints["remote_ip_addresses"])
            check_type(argname="argument status_info", value=status_info, expected_type=type_hints["status_info"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if ip_space is not None:
            self._values["ip_space"] = ip_space
        if name is not None:
            self._values["name"] = name
        if remote_ip_addresses is not None:
            self._values["remote_ip_addresses"] = remote_ip_addresses
        if status_info is not None:
            self._values["status_info"] = status_info

    @builtins.property
    def ip_space(self) -> typing.Optional[builtins.str]:
        '''IPspace name of the local intercluster LIFs.

        Assumes Default IPspace if not provided.

        :schema: ClusterPeerInfo#IpSpace
        '''
        result = self._values.get("ip_space")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''Optional name for the cluster peer relationship.

        By default, it is the name of the remote cluster.

        :schema: ClusterPeerInfo#Name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def remote_ip_addresses(self) -> typing.Optional[typing.List[builtins.str]]:
        '''Addresses of the remote peers.

        Assumes existing intercluster LIFs of remote cluster if not provided.

        :schema: ClusterPeerInfo#RemoteIpAddresses
        '''
        result = self._values.get("remote_ip_addresses")
        return typing.cast(typing.Optional[typing.List[builtins.str]], result)

    @builtins.property
    def status_info(self) -> typing.Optional["ClusterPeerStatus"]:
        '''Status of the cluster peer relationship.

        :schema: ClusterPeerInfo#StatusInfo
        '''
        result = self._values.get("status_info")
        return typing.cast(typing.Optional["ClusterPeerStatus"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ClusterPeerInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.ClusterPeerStatus",
    jsii_struct_bases=[],
    name_mapping={"state": "state", "update_time": "updateTime"},
)
class ClusterPeerStatus:
    def __init__(
        self,
        *,
        state: typing.Optional["ClusterPeerStatusState"] = None,
        update_time: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param state: The current state of the cluster peer relationship. Possible values are 'available', 'partial', 'unavailable', 'pending' and 'unidentified'.
        :param update_time: The last time the status of the peer cluster was updated.

        :schema: ClusterPeerStatus
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0885d1065169c99382599c6a5c8a197add31ef80568d8ff7dadf1e342dd8dc6e)
            check_type(argname="argument state", value=state, expected_type=type_hints["state"])
            check_type(argname="argument update_time", value=update_time, expected_type=type_hints["update_time"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if state is not None:
            self._values["state"] = state
        if update_time is not None:
            self._values["update_time"] = update_time

    @builtins.property
    def state(self) -> typing.Optional["ClusterPeerStatusState"]:
        '''The current state of the cluster peer relationship.

        Possible values are 'available', 'partial', 'unavailable', 'pending' and 'unidentified'.

        :schema: ClusterPeerStatus#State
        '''
        result = self._values.get("state")
        return typing.cast(typing.Optional["ClusterPeerStatusState"], result)

    @builtins.property
    def update_time(self) -> typing.Optional[builtins.str]:
        '''The last time the status of the peer cluster was updated.

        :schema: ClusterPeerStatus#UpdateTime
        '''
        result = self._values.get("update_time")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ClusterPeerStatus(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.ClusterPeerStatusState"
)
class ClusterPeerStatusState(enum.Enum):
    '''The current state of the cluster peer relationship.

    Possible values are 'available', 'partial', 'unavailable', 'pending' and 'unidentified'.

    :schema: ClusterPeerStatusState
    '''

    AVAILABLE = "AVAILABLE"
    '''available.'''
    PARTIAL = "PARTIAL"
    '''partial.'''
    UNAVAILABLE = "UNAVAILABLE"
    '''unavailable.'''
    PENDING = "PENDING"
    '''pending.'''
    UNIDENTIFIED = "UNIDENTIFIED"
    '''unidentified.'''


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.FsxnDestination",
    jsii_struct_bases=[],
    name_mapping={
        "file_system_id": "fileSystemId",
        "fsx_admin_password_source": "fsxAdminPasswordSource",
        "link_arn": "linkArn",
    },
)
class FsxnDestination:
    def __init__(
        self,
        *,
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
    ) -> None:
        '''
        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.

        :schema: FsxnDestination
        '''
        if isinstance(fsx_admin_password_source, dict):
            fsx_admin_password_source = PasswordSource(**fsx_admin_password_source)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__4667f499e8f102881f1ce68465f8a7b9ceac25988fc7a0a416be939090def5ee)
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument fsx_admin_password_source", value=fsx_admin_password_source, expected_type=type_hints["fsx_admin_password_source"])
            check_type(argname="argument link_arn", value=link_arn, expected_type=type_hints["link_arn"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "file_system_id": file_system_id,
            "fsx_admin_password_source": fsx_admin_password_source,
            "link_arn": link_arn,
        }

    @builtins.property
    def file_system_id(self) -> builtins.str:
        '''The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.

        :schema: FsxnDestination#FileSystemId
        '''
        result = self._values.get("file_system_id")
        assert result is not None, "Required property 'file_system_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def fsx_admin_password_source(self) -> "PasswordSource":
        '''The password source for the FSx admin user.

        :schema: FsxnDestination#FsxAdminPasswordSource
        '''
        result = self._values.get("fsx_admin_password_source")
        assert result is not None, "Required property 'fsx_admin_password_source' is missing"
        return typing.cast("PasswordSource", result)

    @builtins.property
    def link_arn(self) -> builtins.str:
        '''The ARN of the AWS Lambda function that will be invoked to manage the resource.

        :schema: FsxnDestination#LinkArn
        '''
        result = self._values.get("link_arn")
        assert result is not None, "Required property 'link_arn' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FsxnDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.PasswordSource",
    jsii_struct_bases=[],
    name_mapping={"secret": "secret"},
)
class PasswordSource:
    def __init__(
        self,
        *,
        secret: typing.Union["SecretSource", typing.Dict[builtins.str, typing.Any]],
    ) -> None:
        '''
        :param secret: A reference to the source of the password, typically an AWS Secrets Manager secret.

        :schema: PasswordSource
        '''
        if isinstance(secret, dict):
            secret = SecretSource(**secret)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__aea743c40fc16438e065a0c2acd6e4266a660f1cff61b2d0b9df7f0be9f1dbd1)
            check_type(argname="argument secret", value=secret, expected_type=type_hints["secret"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "secret": secret,
        }

    @builtins.property
    def secret(self) -> "SecretSource":
        '''A reference to the source of the password, typically an AWS Secrets Manager secret.

        :schema: PasswordSource#Secret
        '''
        result = self._values.get("secret")
        assert result is not None, "Required property 'secret' is missing"
        return typing.cast("SecretSource", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PasswordSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-clusterpeer.SecretSource",
    jsii_struct_bases=[],
    name_mapping={"secret_arn": "secretArn", "secret_key": "secretKey"},
)
class SecretSource:
    def __init__(self, *, secret_arn: builtins.str, secret_key: builtins.str) -> None:
        '''
        :param secret_arn: The ARN of the secret stored in AWS Secrets Manager.
        :param secret_key: Reference for the SecretKey. The actual password is stored in AWS Secret Manager.

        :schema: SecretSource
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__daa246bbb454b4e0360e7811ee4cc03003f4ad7bd7dabf875a0f5c00c6c486d2)
            check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
            check_type(argname="argument secret_key", value=secret_key, expected_type=type_hints["secret_key"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "secret_arn": secret_arn,
            "secret_key": secret_key,
        }

    @builtins.property
    def secret_arn(self) -> builtins.str:
        '''The ARN of the secret stored in AWS Secrets Manager.

        :schema: SecretSource#SecretArn
        '''
        result = self._values.get("secret_arn")
        assert result is not None, "Required property 'secret_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def secret_key(self) -> builtins.str:
        '''Reference for the SecretKey.

        The actual password is stored in AWS Secret Manager.

        :schema: SecretSource#SecretKey
        '''
        result = self._values.get("secret_key")
        assert result is not None, "Required property 'secret_key' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CfnClusterPeer",
    "CfnClusterPeerProps",
    "CfnClusterPeerPropsEncryption",
    "ClusterPeerInfo",
    "ClusterPeerStatus",
    "ClusterPeerStatusState",
    "FsxnDestination",
    "PasswordSource",
    "SecretSource",
]

publication.publish()

def _typecheckingstub__d39f67cfc2675a7cba4b59b49a311a2ad559e3e34f2bf2d63301ef90806e1673(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    fsxn_destination_info: typing.Union[FsxnDestination, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
    destination_cluster_peer: typing.Optional[typing.Union[ClusterPeerInfo, typing.Dict[builtins.str, typing.Any]]] = None,
    encryption: typing.Optional[CfnClusterPeerPropsEncryption] = None,
    source_cluster_peer: typing.Optional[typing.Union[ClusterPeerInfo, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__a4fff69eb8122f4cd873011b3c958000430d60ee8d1f6a645518139c95bfbc99(
    *,
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    fsxn_destination_info: typing.Union[FsxnDestination, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
    destination_cluster_peer: typing.Optional[typing.Union[ClusterPeerInfo, typing.Dict[builtins.str, typing.Any]]] = None,
    encryption: typing.Optional[CfnClusterPeerPropsEncryption] = None,
    source_cluster_peer: typing.Optional[typing.Union[ClusterPeerInfo, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__ae24ad49b7d1edca270fc0fd1fb3c66c71571d1e4e44b7ef2dbc0df5e3125026(
    *,
    ip_space: typing.Optional[builtins.str] = None,
    name: typing.Optional[builtins.str] = None,
    remote_ip_addresses: typing.Optional[typing.Sequence[builtins.str]] = None,
    status_info: typing.Optional[typing.Union[ClusterPeerStatus, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__0885d1065169c99382599c6a5c8a197add31ef80568d8ff7dadf1e342dd8dc6e(
    *,
    state: typing.Optional[ClusterPeerStatusState] = None,
    update_time: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__4667f499e8f102881f1ce68465f8a7b9ceac25988fc7a0a416be939090def5ee(
    *,
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__aea743c40fc16438e065a0c2acd6e4266a660f1cff61b2d0b9df7f0be9f1dbd1(
    *,
    secret: typing.Union[SecretSource, typing.Dict[builtins.str, typing.Any]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__daa246bbb454b4e0360e7811ee4cc03003f4ad7bd7dabf875a0f5c00c6c486d2(
    *,
    secret_arn: builtins.str,
    secret_key: builtins.str,
) -> None:
    """Type checking stubs"""
    pass
